# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## [Unreleased]

## [0.3.0][] - 2019-08-17

### Added

- Added `show` and `download` subcommands.

## [0.2.0][] - 2019-08-14

### Changed

- Changed package name to `backwork-upload-cos`

## [0.1.0][] - 2019-05-24

### Added

- Initial release

[unreleased]: https://github.com/IBM/backwork-upload-cos/compare/0.3.0...HEAD
[0.3.0]: https://github.com/IBM/backwork-upload-cos/compare/0.2.0...0.3.0
[0.2.0]: https://github.com/IBM/backwork-upload-cos/compare/0.1.0...0.2.0
